@@ -9,7 +9,6 @@ import json
 import requests
 import re
 import logging
-from typing import List
 from requests.exceptions import HTTPError, ConnectionError, SSLError, Timeout, ConnectTimeout, ReadTimeout
 from .AuthToken import AuthToken
 from .util.Util import AuthenticationFailedError
@@ -55,7 +54,7 @@ class AnaplanAuthentication(object):
 		try:
 			json_response = json.loads(response)
 		except ValueError as e:
-			logger.error(f"Error loading response JSON {e}")
+			logger.error(f"Error loading response JSON {e}", exc_info=True)
 
 		# Check that the request was successful, is so extract the AnaplanAuthToken value
 		if 'status' in json_response:
@@ -89,18 +88,18 @@ class AnaplanAuthentication(object):
 			logger.debug("Verifying auth token.")
 			validate = json.loads(requests.get(anaplan_url, headers=header, timeout=(5, 30)).text)
 		except (HTTPError, ConnectionError, SSLError, Timeout, ConnectTimeout, ReadTimeout) as e:
-			logger.error(f"Error verifying auth token {e}")
+			logger.error(f"Error verifying auth token {e}", exc_info=True)
 		except ValueError as e:
-			logger.error(f"Error loading response JSON {e}")
+			logger.error(f"Error loading response JSON {e}", exc_info=True)
 
 		if 'statusMessage' in validate:
 			return validate['statusMessage']
 
 	@staticmethod
-	def refresh_token(token) -> List[str]:
+	def refresh_token(token: str, auth_object: AuthToken) -> None:
 		"""
 		@param token: Token value that is nearing expiry
-		@return: List of strings with renewed token value and expiry time.
+		@param auth_object: AuthToken object to be updated.
 		"""
 		refresh = {}
 		new_token = ""
@@ -111,9 +110,9 @@ class AnaplanAuthentication(object):
 		try:
 			refresh = json.loads(requests.post(url, headers=header, timeout=(5, 30)).text)
 		except (HTTPError, ConnectionError, SSLError, Timeout, ConnectTimeout, ReadTimeout) as e:
-			logger.error(f"Error verifying auth token {e}")
+			logger.error(f"Error verifying auth token {e}", exc_info=True)
 		except ValueError as e:
-			logger.error(f"Error loading response JSON {e}")
+			logger.error(f"Error loading response JSON {e}", exc_info=True)
 		
 		if 'tokenInfo' in refresh:
 			if 'tokenValue' in refresh['tokenInfo']:
@@ -121,4 +120,5 @@ class AnaplanAuthentication(object):
 			if 'expiresAt' in refresh['tokenInfo']:
 				new_expiry = refresh['tokenInfo']['expiresAt']
 
-		return [''.join(["AnaplanAuthToken ", new_token]), new_expiry]
+		auth_object.set_auth_token(''.join(["AnaplanAuthToken ", new_token]))
+		auth_object.set_token_expiry(new_expiry)
