@@ -1,4 +1,5 @@
 import logging
+from functools import partial
 from .Upload import Upload
 
 logger = logging.getLogger(__name__)
@@ -12,7 +13,8 @@ class FileUpload(Upload):
 		:return: None
 		"""
 
-		url = ''.join([super().get_base_url(), super().get_workspace(), "/models/", super().get_model(), "/files/", super().get_file_id()])
+		url = ''.join([super().get_base_url(), super().get_workspace(), "/models/", super().get_model(), "/files/",
+		               super().get_file_id()])
 
 		metadata_update = super().file_metadata(url)
 		# Confirm that the metadata update for the requested file was OK before proceeding with file upload
@@ -20,15 +22,11 @@ class FileUpload(Upload):
 			logger.info("Starting file upload.")
 
 			with open(file, 'rt') as file:
-				file_data = []
 				chunk_num = 0
-				while True:
-					buf = file.readlines((1024 * 1024) * chunk_size)
-					if not buf:
-						break
-					for item in buf:
-						file_data.append(item)
-					complete = super().file_data(url, chunk_num, ''.join(file_data).encode('utf-8'))
+
+				for data in iter(partial(file.read, chunk_size * (1024 ** 2)), ''):
+					complete = super().file_data(''.join([url, "/chunks/", str(chunk_num)]), chunk_num,
+					                             data.encode('utf-8'))
 					chunk_num += 1
 
 			if complete:
